import {Image, View} from "@tarojs/components";
import {HomeApi} from "@/api";
import {useEffect, useState} from "react";
import Tabs, {OnChangOpt, TabList} from "@/components/tabs/tabs";
import Empty from "@/components/empty/empty";
import Taro from "@tarojs/taro";

const Profession = () => {
  const [tabs, setTabs] = useState<TabList[]>([])
  const [page, setPage] = useState(1)
  const [categoryId, setCategoryId] = useState<number | null>(null)
  const [data, setData] = useState<Kill[]>([])
  const [total, setTotal] = useState(0)

  async function getData(categoryId: number) {
    const res = await HomeApi.skillList(categoryId, page, 10)
    setTotal(res.total)
    setData(res.data)
  }

  useEffect(() => {
    categoryId && getData(categoryId)
  }, [categoryId, page])

  async function getCategory() {
    const res = await HomeApi.skillCategory()
    const newTabs = res.map<TabList>(d => ({title: d.name, value: d.id}))
    setTabs(newTabs)
    setCategoryId(newTabs[0].value as number)
  }

  function tabsChange(tab: OnChangOpt) {
    setPage(1)
    setCategoryId(tab.tab?.value as number)
  }

  function jump(url: string) {
    Taro.navigateTo({url: '/pages/preview/videoFull/videoFull?url=' + url})
  }

  useEffect(() => {
    getCategory().then()
  }, [])

  return (
    <>
      <View className='bg-white'>
        <Tabs tabList={tabs} onChange={tabsChange}/>
      </View>

      {
        data.length > 0
          ? data.map(d => <View className='flex bg-white mt-2' onClick={() => jump(d.resource.url)}>
            <Image src={d.url_path} style={{width: '200px', height: '100px', marginRight: '10px'}}/>
            <View className='text-ellipsis'>{d.resource.name}</View>
          </View>)
          : <Empty name='暂无数据'/>
      }
    </>
  )
}
export default Profession
